@@ -1,5 +1,6 @@
-__version__ = "2.2.3"
+__version__ = "2.4.0"
 
+import fullmetalalchemy.connection as connection
 import fullmetalalchemy.create as create
 import fullmetalalchemy.delete as delete
 import fullmetalalchemy.drop as drop
@@ -7,6 +8,7 @@ import fullmetalalchemy.features as features
 import fullmetalalchemy.insert as insert
 import fullmetalalchemy.records as records
 import fullmetalalchemy.select as select
+import fullmetalalchemy.session as session
 import fullmetalalchemy.type_convert as type_convert
 import fullmetalalchemy.update as update
 from fullmetalalchemy.batch import BatchProcessor, BatchResult
@@ -20,6 +22,7 @@ __all__ = [
     "BatchResult",
     "SessionTable",
     "Table",
+    "connection",
     "create",
     "create_engine",
     "delete",
@@ -31,6 +34,7 @@ __all__ = [
     "insert",
     "records",
     "select",
+    "session",
     "type_convert",
     "update",
 ]
