@@ -6,65 +6,17 @@ import typing as _t
 
 import sqlalchemy as _sa
 import sqlalchemy.engine as _sa_engine
-import sqlalchemy.orm.session as _sa_session
 
 import fullmetalalchemy.exceptions as _ex
 import fullmetalalchemy.features as _features
-import fullmetalalchemy.types as _types
+import fullmetalalchemy.session as _session
 
-
-def delete_records_session(
-    table: _t.Union[_sa.Table, str],
-    column_name: str,
-    values: _t.Sequence[_t.Any],
-    session: _sa_session.Session,
-) -> None:
-    """
-    Delete records from SQL table that match passed values in column.
-    Adds deletes to passed session.
-
-    Parameters
-    ----------
-    table : sa.Table | str
-        SqlAlchemy Table or table name
-    column_name : str
-        SQL table column name to match values
-    values : Sequence
-        values to match in SQL table column
-    session : SqlAlchemy Session
-        SqlAlchemy connection session
-
-    Returns
-    -------
-    None
-
-    Example
-    -------
-    >>> import fullmetalalchemy as fa
-
-    >>> engine, table = fa.get_engine_table('sqlite:///data/test.db', 'xy')
-    >>> fa.select.select_records_all(table)
-    [{'id': 1, 'x': 1, 'y': 2},
-     {'id': 2, 'x': 2, 'y': 4},
-     {'id': 3, 'x': 4, 'y': 8},
-     {'id': 4, 'x': 8, 'y': 11}]
-
-    >>> session = fa.features.get_session(engine)
-    >>> fa.delete.delete_records_session(table, 'id', [1], session)
-    >>> session.commit()
-    >>> fa.select.select_records_all(table)
-    [{'id': 2, 'x': 2, 'y': 4},
-     {'id': 3, 'x': 4, 'y': 8},
-     {'id': 4, 'x': 8, 'y': 11}]
-
-    See Also
-    --------
-    fullmetalalchemy.delete.delete_records_by_values_session
-    """
-    table = _features.str_to_table(table, session)
-    col = _features.get_column(table, column_name)
-    delete_stmt = _sa.delete(table).where(col.in_(values))
-    session.execute(delete_stmt)
+# Re-export session functions for backward compatibility
+delete_records_session = _session.delete_records
+delete_record_by_values_session = _session.delete_record_by_values
+delete_records_by_values_session = _session.delete_records_by_values
+delete_all_records_session = _session.delete_all_records
+_build_delete_from_record = _session._build_delete_from_record
 
 
 def delete_records(
@@ -114,8 +66,8 @@ def delete_records(
     """
     table, engine = _ex.convert_table_engine(table, engine)
     session = _features.get_session(engine)
-    delete_records_session(table, column_name, values, session)
     try:
+        _session.delete_records(table, column_name, values, session)
         session.commit()
     except Exception as e:
         session.rollback()
@@ -162,177 +114,13 @@ def delete_records_by_values(
     table, engine = _ex.convert_table_engine(table, engine)
     session = _features.get_session(engine)
     try:
-        delete_records_by_values_session(table, records, session)
+        _session.delete_records_by_values(table, records, session)
         session.commit()
     except Exception as e:
         session.rollback()
         raise e
 
 
-def delete_record_by_values_session(
-    table: _t.Union[_sa.Table, str], record: _types.Record, session: _sa_session.Session
-) -> None:
-    """
-    Deletes a single row from a table based on the values in the specified record.
-
-    Parameters
-    ----------
-    table : Union[sqlalchemy.Table, str]
-        The table to delete from. Can either be a `sqlalchemy.Table` object
-        or a string containing the name of the table.
-    record : fullmetalalchemy.types.Record
-        A dictionary of column names and values representing the row to delete.
-    session : sqlalchemy.orm.session.Session
-        The session object to use for the database transaction.
-
-    Returns
-    -------
-    None
-
-    Examples
-    --------
-    >>> import fullmetalalchemy as fa
-
-    >>> engine, table = fa.get_engine_table('sqlite:///data/test.db', 'xy')
-    >>> fa.select.select_records_all(table)
-    [{'id': 1, 'x': 1, 'y': 2},
-     {'id': 2, 'x': 2, 'y': 4},
-     {'id': 3, 'x': 4, 'y': 8},
-     {'id': 4, 'x': 8, 'y': 11}]
-
-    >>> session = fa.features.get_session(engine)
-    >>> fa.delete.delete_record_by_values_session(table, {'id': 1, 'x': 1, 'y': 2}, session)
-    >>> session.commit()
-    >>> fa.select.select_records_all(table)
-    [{'id': 2, 'x': 2, 'y': 4},
-     {'id': 3, 'x': 4, 'y': 8},
-     {'id': 4, 'x': 8, 'y': 11}]
-
-    """
-    table = _features.str_to_table(table, session)
-    delete = _build_delete_from_record(table, record)
-    session.execute(delete)
-
-
-def delete_records_by_values_session(
-    table: _t.Union[_sa.Table, str],
-    records: _t.Sequence[_types.Record],
-    session: _sa_session.Session,
-) -> None:
-    """
-    Delete records from the specified table that match the given records
-    by values using the provided session.
-
-    Parameters
-    ----------
-    table : Union[Table, str]
-        The SQLAlchemy table object or name of the table to delete records from.
-    records : Sequence[Record]
-        A sequence of records to delete from the table. Each record is a dictionary
-        with keys as column names and values as the value to match.
-    session : Session
-        The SQLAlchemy session to use for the database operation.
-
-    Returns
-    -------
-    None
-
-    Example
-    -------
-    >>> import sqlalchemize as sz
-
-    >>> engine, table = sz.get_engine_table('sqlite:///data/test.db', 'xy')
-    >>> select_records_all(table)
-    [{'id': 1, 'x': 1, 'y': 2},
-     {'id': 2, 'x': 2, 'y': 4},
-     {'id': 3, 'x': 4, 'y': 8},
-     {'id': 4, 'x': 8, 'y': 11}]
-
-    >>> session = sz.features.get_session(engine)
-    >>> sz.delete.delete_records_by_values_session(table, [{'id': 3}, {'x': 2}], session)
-    >>> session.commit()
-    >>> sz.select.select_records_all(table)
-    [{'id': 1, 'x': 1, 'y': 2},
-     {'id': 4, 'x': 8, 'y': 11}]
-    """
-    table = _features.str_to_table(table, session)
-    for record in records:
-        delete_record_by_values_session(table, record, session)
-
-
-def _build_delete_from_record(table: _sa.Table, record: _types.Record) -> _sa.sql.Delete:
-    """
-    Builds a SQL DELETE statement for deleting a record from a table based on a
-    dictionary of key-value pairs.
-
-    Parameters
-    ----------
-    table : Union[sqlalchemy.Table, str]
-        The table object or name to delete from.
-    record : Dict[str, Any]
-        A dictionary of key-value pairs representing the record to delete.
-
-    Returns
-    -------
-    sqlalchemy.sql.expression.Delete
-        A SQL DELETE statement for deleting a record from the table based on the given record.
-
-    Example
-    -------
-    >>> from sqlalchemy import Table, Column, Integer, MetaData
-
-    >>> metadata = MetaData()
-    >>> table = Table('mytable', metadata,
-    ...               Column('id', Integer, primary_key=True),
-    ...               Column('name', String))
-    >>> record = {'id': 1, 'name': 'test'}
-    >>> delete_statement = _build_delete_from_record(table, record)
-    >>> print(delete_statement)
-    DELETE FROM mytable WHERE mytable.id = :id_1 AND mytable.name = :name_1
-    """
-    d = _sa.delete(table)
-    for column, value in record.items():
-        d = d.where(table.c[column] == value)
-    return d
-
-
-def delete_all_records_session(
-    table: _t.Union[_sa.Table, str], session: _sa_session.Session
-) -> None:
-    """
-    Delete all records from the specified table.
-
-    Parameters
-    ----------
-    table : Union[Table, str]
-        The table to delete records from. It can be either a sqlalchemy
-        Table object or a table name.
-    session : Session
-        The session to use to execute the query.
-
-    Returns
-    -------
-    None
-
-    Examples
-    --------
-    >>> import sqlalchemize as sz
-
-    >>> engine, table = sz.get_engine_table('sqlite:///data/test.db', 'xy')
-    >>> sz.select.select_records_all(table)
-    [{'id': 1, 'x': 1, 'y': 2}, {'id': 2, 'x': 2, 'y': 4}]
-
-    >>> session = sz.features.get_session(engine)
-    >>> sz.delete.delete_all_records_session(table, session)
-    >>> session.commit()
-    >>> sz.select.select_records_all(table)
-    []
-    """
-    table = _features.str_to_table(table, session)
-    query = _sa.delete(table)
-    session.execute(query)
-
-
 def delete_all_records(
     table: _t.Union[_sa.Table, str], engine: _t.Optional[_sa_engine.Engine] = None
 ) -> None:
@@ -372,7 +160,91 @@ def delete_all_records(
     table, engine = _ex.convert_table_engine(table, engine)
     session = _features.get_session(engine)
     try:
-        delete_all_records_session(table, session)
+        _session.delete_all_records(table, session)
+        session.commit()
+    except Exception as e:
+        session.rollback()
+        raise e
+
+
+def delete_records_by_primary_keys(
+    table: _t.Union[_sa.Table, str],
+    primary_key_values: _t.Sequence[_t.Union[_t.Any, _t.Tuple[_t.Any, ...]]],
+    engine: _t.Optional[_sa_engine.Engine] = None,
+) -> None:
+    """
+    Delete records by primary key values (single or composite).
+
+    More efficient than delete_records_by_values() when you only have
+    primary key values, not full records.
+
+    Parameters
+    ----------
+    table : Union[Table, str]
+        Table object or name
+    primary_key_values : Sequence[Union[Any, Tuple[Any, ...]]]
+        For single PK: List[Any]
+        For composite PK: List[Tuple[Any, ...]]
+    engine : Optional[Engine]
+        Engine or connection
+
+    Returns
+    -------
+    None
+
+    Raises
+    ------
+    ValueError
+        If table has no primary key
+        If PK tuple lengths don't match for composite PK
+
+    Examples
+    --------
+    >>> import fullmetalalchemy as fa
+    >>> # Single PK
+    >>> fa.delete.delete_records_by_primary_keys(
+    ...     'users', [1, 2, 3], engine
+    ... )
+    >>> # Composite PK
+    >>> fa.delete.delete_records_by_primary_keys(
+    ...     'memberships',
+    ...     [(1, 10), (2, 20)],
+    ...     engine
+    ... )
+    """
+    table, engine = _ex.convert_table_engine(table, engine)
+
+    pk_names = _features.primary_key_names(table)
+    if not pk_names:
+        raise ValueError(f"Table {table.name} has no primary key")
+
+    session = _features.get_session(engine)
+    try:
+        if len(pk_names) == 1:  # Single PK
+            # primary_key_values should be List[Any]
+            column = _features.get_column(table, pk_names[0])
+            stmt = _sa.delete(table).where(column.in_(primary_key_values))
+            session.execute(stmt)
+        else:  # Composite PK
+            # primary_key_values should be List[Tuple[Any, ...]]
+            # Validate tuple lengths
+            for pk_tuple in primary_key_values:
+                if not isinstance(pk_tuple, tuple):
+                    raise ValueError(
+                        f"For composite PK, values must be tuples, got {type(pk_tuple)}"
+                    )
+                if len(pk_tuple) != len(pk_names):
+                    raise ValueError(
+                        f"PK tuple length {len(pk_tuple)} doesn't match "
+                        f"number of PK columns {len(pk_names)}"
+                    )
+
+            # Build (col1, col2) IN ((val1, val2), ...) query
+            pk_columns = [_features.get_column(table, pk_name) for pk_name in pk_names]
+            pk_tuple_expr = _sa.tuple_(*pk_columns)
+            stmt = _sa.delete(table).where(pk_tuple_expr.in_(primary_key_values))
+            session.execute(stmt)
+
         session.commit()
     except Exception as e:
         session.rollback()
